@@ -61,3 +61,19 @@ function(x, file='data',ncolumns=1,append=FALSE, sep=" ",...){
 	)
 }
 
+`[.nmctl` <- function (x, ..., drop = TRUE){
+    cl <- oldClass(x)
+    class(x) <- NULL
+    val <- NextMethod("[")
+    class(val) <- cl
+    val
+}
+
+`[[.nmctl` <- function (x, ..., drop = TRUE) 
+{
+    cl <- oldClass(x)
+    class(x) <- NULL
+    val <- NextMethod("[[")
+    class(val) <- cl
+    val
+}
