@@ -34,6 +34,7 @@ function (
 	ctlfile = filename(streams,run,'.ctl'),
 	remove  = c('^F[ISRC]','^OU','^nonmem.exe','^nul$',if(fdata)c('^FD','^PR')),
 	sync=if(boot)'n'else'y',
+	interface='nm.pl',
 	...
 ){
   #Define some functions.
@@ -79,7 +80,7 @@ function (
 	  if(file.exists(parfile))file.remove(parfile)
 	  if(file.exists(msffile))file.remove(msffile)
 	  purge.dir(final(rundir),nice)
-	  if(rundir!=final(rundir))purge.dir(rundir)
+	  if(rundir!=final(rundir))purge.dir(rundir) #deliberately not "nice"
 	  dir.create(rundir, showWarnings = FALSE)
 	  dname <- getdname(ctlfile)
 	  #The next error trap is redundant: prevents identical trap in getCovs()
@@ -104,6 +105,7 @@ function (
 	execute=execute,
 	split=split,
 	sync=sync,
+	interface=interface,
 	...
   )
   #Clean up.
@@ -118,7 +120,7 @@ function (
 	
 	  #Diagnostics
 	  if(!udef)
-	   if(command!='')if(nmVersion(config(dirname(command))) < 7)
+	   if(command!='' & interface=='nm.pl')if(nmVersion(config(dirname(command))) < 7)
 	    tryCatch(
     		setCwres(
     			cwres=getCwres(
@@ -179,7 +181,9 @@ function (
   	if(file_test('-d',dir)){
   		files <- dir(dir,full.names=TRUE,all.files=!nice)
   		files <- files[!files %in% grep('\\.$',files,value=TRUE)]
-  		if(length(files))file.remove(files)
+  		isDir <- file_test('-d',files)
+  		if(length(files[!isDir]))file.remove(files[!isDir])
+  		lapply(files[isDir],purge.dir,nice=nice)
   		if(!nice)unlink(dir, recursive=TRUE)
   	}
   }
@@ -190,7 +194,7 @@ function (
   		if(length(files))file.remove(paste(dir,files,sep='/'))
   	}
   }
-   episcript <- function(script,...){
+  episcript <- function(script,...){
 	 extras <- list(...)
 	 args <- names(extras)
 	 lapply(
